package com.logicbig.example;

import javax.persistence.Cache;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.Persistence;

public class ExampleMain {
    private static EntityManagerFactory entityManagerFactory =
            Persistence.createEntityManagerFactory("example-unit");

    public static void main(String[] args) {
        try {
            persistEntity();
            loadEntity();
            evictFromCache();
            printCacheState();
        } finally {
            entityManagerFactory.close();
        }
    }

    public static void persistEntity() {
        Employee employee = new Employee();
        employee.setName("Dawn");
        employee.setDept("IT");
        EntityManager em = entityManagerFactory.createEntityManager();
        em.getTransaction().begin();
        em.persist(employee);
        em.getTransaction().commit();
        System.out.println("Employee inserted: " + employee);
        em.close();
        printCacheState();
    }

    private static void loadEntity() {
        EntityManager em = entityManagerFactory.createEntityManager();
        Employee employee = em.find(Employee.class, 1L);
        System.out.println("Employee loaded: " + employee);
        em.close();
        printCacheState();
    }

    private static void printCacheState() {
        Cache cache = entityManagerFactory.getCache();
        boolean contains = cache.contains(Employee.class, 1L);
        System.out.printf("Cache#contains(): %s%n", contains);
    }

    private static void evictFromCache() {
        Cache cache = entityManagerFactory.getCache();
        cache.evict(Employee.class, 1L);
        System.out.println("entity evicted");
    }
}